package com.abi.qms.platform.controller.console;

import com.abi.qms.platform.dto.req.*;
import com.abi.qms.platform.dto.res.GetMaterialRes;
import com.abi.qms.platform.dto.res.ListBrandForSelectRes;
import com.abi.qms.platform.dto.res.ListMaterialForSelectRes;
import com.abi.qms.platform.dto.res.ListMaterialRes;
import com.abi.qms.platform.service.MaterialService;
import com.abi.task.common.api.base.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * <p>
 * 物料管理
 * </p>
 *
 * @author Andy.Tan
 */
@Slf4j
@RestController
@RequestMapping("material")
@Api(tags = "物料管理")
public class MaterialController {

    @Autowired
    private MaterialService materialService;


    @ApiOperation("新增物料")
        @PostMapping("addMaterial")
    public BaseResponse addMaterial(@Validated @RequestBody AddMaterialReq addMaterialReq) throws Exception{
        //新增物料
        materialService.addMaterial(addMaterialReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("编辑物料")
    @PostMapping("updateMaterial")
    public BaseResponse updateMaterial(@Validated @RequestBody UpdateMaterialReq updateMaterialReq) throws Exception{
        //编辑物料
        materialService.updateMaterial(updateMaterialReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("分页查询物料")
    @GetMapping("listMaterial")
    public BaseResponse<ListMaterialRes> listMaterial(@Validated ListMaterialReq listMaterialReq) throws Exception{
        //分页查询物料
        ListMaterialRes result = materialService.listMaterial(listMaterialReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("查询物料明细")
    @GetMapping("getMaterial")
    public BaseResponse<GetMaterialRes> getMaterial(@Validated GetMaterialReq getMaterialReq) throws Exception{
        //查询物料明细
        GetMaterialRes  result = materialService.getMaterial(getMaterialReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("物料启用")
    @PostMapping("enableMaterial")
    public BaseResponse enableMaterial(@Validated @RequestBody EnableMaterialReq enableMaterialReq) throws Exception{
        //物料启用
        materialService.enableMaterial(enableMaterialReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("物料禁用")
    @PostMapping("disableMaterial")
    public BaseResponse disableMaterial(@Validated @RequestBody DisableMaterialReq disableMaterialReq) throws Exception{
        //物料禁用
        materialService.disableMaterial(disableMaterialReq);
        //包装出参
        return BaseResponse.create();
    }

    @ApiOperation("下拉选择物料列表")
    @GetMapping("listMaterialForSelect")
    public BaseResponse<ListMaterialForSelectRes> listMaterialForSelect(@Validated ListMaterialForSelectReq listMaterialForSelectReq) throws Exception{
        //下拉选择物料列表
        ListMaterialForSelectRes  result = materialService.listMaterialForSelect(listMaterialForSelectReq);
        //包装出参
        return BaseResponse.create(result);
    }

    @ApiOperation("下拉选择品牌列表")
    @GetMapping("listBrandForSelect")
    public BaseResponse<ListBrandForSelectRes> listBrandForSelect(@Validated ListBrandForSelectReq listBrandForSelectReq) throws Exception{
        //下拉选择品牌列表
        ListBrandForSelectRes  result = materialService.listBrandForSelect(listBrandForSelectReq);
        //包装出参
        return BaseResponse.create(result);
    }

}








